#################################################################################
# Created       : Martin Foster
# Modified      : 01/22/2000
#################################################################################
#
# Who - Modules part of Webchat designed to determine who is on 
# Copyright (C) 2000  Martin Foster
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#
# Author of this script can be contacted at the following:
#       E-Mail  : mfoster@redwhite.com
#       Address : Suite 209 - 355 5th Ave NE
#                 Calgary, Alberta
#                 T2R 0K9
#
#################################################################################

package Webchat::Who;						# Package name

use Webchat::Dbm;						# DBM handling
use Webchat::Param;						# Parameter handler
use Webchat::Login;						# Login handler


#################################################################################
# Data Members
#################################################################################

#################################################################################
# Sub-Routines
#################################################################################

#####################
# Who
#
# Simply lists who is on at the time

sub who                                                         # Database, CGI, Parameter list
{
	#####################
	# Data members
	my $Database = shift;					# Database handle
	my $cgi = shift;					# CGI handle
	my $param = shift;					# Parameter list
	my $choice = shift;					# Choice of the matter

	my $entries;						# Amount of entries
	my $realm;						# Realms title
	my $color = 0;						# Colour change
	my $delay;						# Timestamp delay

	my @who;						# Who is on list

	my %realm;						# Realm hash


	#####################
	# Program area

	# Link DBM to hash
	Webchat::Dbm::DBMOpenRealm(\%realm);

	# Handle information
	$delay = (time - $realm{'SetTimeout'});
	$param->{'ROOM'} = Webchat::Login::Unmangle($param->{'ROOM'});

	# Retreive and format values for who is on
	Webchat::Database::GetListWho($Database, \@who, $param->{'ROOM'}, $delay);
	my $entries = @who;					# Amount of entries


	# HTML Display
	# Title only if displayed
	if ($choice == 0)
	{
		# Prepare and display title
		$realm = $realm{'TagTitleRealm'};		# As to not change DBM
		$realm =~ s/REALM/$param->{'ROOM'}/g;		# Replace REALM with real name
		print "$realm\n<BR>\n";				# Display realm
	}

	# Table top
	print "<CENTER>\n<TABLE WIDTH=\"500\">\n";

	# If used as an Entrance
	if ($choice == 0)
	{
		print "\t<TR>\n";				# Row
		print "\t\t", $cgi->start_form('POST', $realm{'LnkRealm'}, 'application/x-www-form-urlencoded');
		print "\t\t<TD ROWSPAN=\"$entries\">";		# Column with button
		print $cgi->submit($realm{'TxtSubmit'});	# Button
		print "</TD>\n";				# End of column

		Webchat::Param::EmbedNormal($Database, $cgi, $param);
		print "\t\t", $cgi->end_form(), "\n";		# End of form
	}

	# Format line
	foreach $_ (@who)
	{
		# Use of tag
		if ($choice != 0)
		{ print "\t<TR>\n"; }				# Row tag
 		else
		{ $choice = 1; }				# Alternate

		# Secondary colour
		if ($color == 0)
		{
			# Print then alternate to other colour
			print "\t\t<TD BGCOLOR=\"$realm{'SetPriColour'}\">";
			print "<FONT COLOR=\"$realm{'SetTextColour'}\"><B>$_</B></FONT></TD>\n";
			$color = 1;				# Alternate
		}

		# Secondary colour
		elsif ($color == 1)
		{
			# Print then alternate to other colour
			print "\t\t<TD BGCOLOR=\"$realm{'SetSecColour'}\">";
			print "<FONT COLOR=\"$realm{'SetTextColour'}\"><B>$_</B></FONT></TD>\n";
			$color = 0;				# Alternate
		}

		print "\t</TR>\n";				# Ending row tag
	}

	print "</TABLE>\n</CENTER>\n";				# End of table

	# Unlink DBM to hash
	Webchat::Dbm::DBMClose(\%realm);
}

# Alias for Entrace
sub WhoEntrance
{ who(shift, shift, shift, 0); }

# Alias for Normal
sub WhoNormal
{ who(shift, shift, shift, 1);}

1;								# Return true


